/* Function to invalidate browser cache */

const invalidateCache = () => {
  caches.keys().then(function (names) {
    for (let name of names) caches.delete(name);
  });
};

/* Function to register service worker */

const registerSW = () => {
  if ("serviceWorker" in navigator) {
    navigator.serviceWorker
      .register("/sw.js", { scope: "/" })
      .then(function () {
        console.log("Ready to roll!");
      });
  }
};

/* Function to unregister service worker */

const unregisterSW = () => {
  navigator.serviceWorker.getRegistrations().then(function (registrations) {
    for (let registration of registrations) {
      registration.unregister();
    }
  });
};

/* Function to fetch website config and configure service worker accordingly */

const getWebsiteConfig = async () => {
  const data = await (await fetch("/api/website-config/")).json();
  websiteConfig = data[0];
  if (!websiteConfig.flags.unregister_sw) {
    console.log("Service Worker is enabled; registering service worker.");
    registerSW();
  }
  if (new Date(websiteConfig.deadline).getTime() < new Date().getTime()) {
    console.warn(
      "Cache has expired; invalidating it and unregistering service worker."
    );
    invalidateCache();
    unregisterSW();
  }
  if (websiteConfig.flags.invalidate_cache) {
    console.warn("Cache is disabled; invalidating it.");
    invalidateCache();
  }
  if (websiteConfig.flags.unregister_sw) {
    console.warn("Service Worker is disabled; unregistering service worker.");
    unregisterSW();
  }
};

/* Things to do after page is fully loaded */

window.onload = () => {
  getWebsiteConfig();
};
